==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_fields/WORKORDERRESOURCEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour WORKORDERRESOURCEID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="WORKORDERRESOURCEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WORKORDERID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RESOURCEID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "WORKORDERRESOURCEID_Type", propOrder = {
    "workorderid",
    "resourceid"
})
public class WORKORDERRESOURCEID_Type {

    @XmlElement(name = "WORKORDERID", required = true)
    protected WOID_Type workorderid;
    @XmlElement(name = "RESOURCEID", required = true)
    protected RESOURCEID_Type resourceid;

    /**
     * Obtient la valeur de la propriété workorderid.
     * 
     * @return
     *     possible object is
     *     {@link WOID_Type }
     *     
     */
    public WOID_Type getWORKORDERID() {
        return workorderid;
    }

    /**
     * Définit la valeur de la propriété workorderid.
     * 
     * @param value
     *     allowed object is
     *     {@link WOID_Type }
     *     
     */
    public void setWORKORDERID(WOID_Type value) {
        this.workorderid = value;
    }

    /**
     * Obtient la valeur de la propriété resourceid.
     * 
     * @return
     *     possible object is
     *     {@link RESOURCEID_Type }
     *     
     */
    public RESOURCEID_Type getRESOURCEID() {
        return resourceid;
    }

    /**
     * Définit la valeur de la propriété resourceid.
     * 
     * @param value
     *     allowed object is
     *     {@link RESOURCEID_Type }
     *     
     */
    public void setRESOURCEID(RESOURCEID_Type value) {
        this.resourceid = value;
    }

}

==> eam-wshub-proxyclient-11.7-2-sources.jar: net/datastream/schemas/mp_fields/WORKORDERRESOURCEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for WORKORDERRESOURCEID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="WORKORDERRESOURCEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WORKORDERID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RESOURCEID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "WORKORDERRESOURCEID_Type", propOrder = {
    "workorderid",
    "resourceid"
})
public class WORKORDERRESOURCEID_Type {

    @XmlElement(name = "WORKORDERID", required = true)
    protected WOID_Type workorderid;
    @XmlElement(name = "RESOURCEID", required = true)
    protected RESOURCEID_Type resourceid;

    /**
     * Gets the value of the workorderid property.
     * 
     * @return
     *     possible object is
     *     {@link WOID_Type }
     *     
     */
    public WOID_Type getWORKORDERID() {
        return workorderid;
    }

    /**
     * Sets the value of the workorderid property.
     * 
     * @param value
     *     allowed object is
     *     {@link WOID_Type }
     *     
     */
    public void setWORKORDERID(WOID_Type value) {
        this.workorderid = value;
    }

    /**
     * Gets the value of the resourceid property.
     * 
     * @return
     *     possible object is
     *     {@link RESOURCEID_Type }
     *     
     */
    public RESOURCEID_Type getRESOURCEID() {
        return resourceid;
    }

    /**
     * Sets the value of the resourceid property.
     * 
     * @param value
     *     allowed object is
     *     {@link RESOURCEID_Type }
     *     
     */
    public void setRESOURCEID(RESOURCEID_Type value) {
        this.resourceid = value;
    }

}
